@@ -56,11 +56,11 @@ class Template(object):
     def __init__(self, template, backend):
         self.template = template
         self.backend = backend
-        self.origin = Origin(name=template.filename, template_name=template.name)
 
-    @property
-    def name(self):
-        return self.template.name
+        self.name = template.name
+        self.origin = Origin(
+            name=template.filename, template_name=template.name
+        )
 
     def render(self, context=None, request=None):
         if context is None:
@@ -99,10 +99,10 @@ class Template(object):
 
                 context = CompatibilityContext(context)
 
-            signals.template_rendered.send(sender=self, template=self,
+            signals.template_rendered.send(sender=self,
+                                           template=self,
                                            context=context)
 
-
         return mark_safe(self.template.render(context))
 
 
@@ -208,8 +208,6 @@ class Jinja2(BaseEngine):
         self._initialize_thirdparty()
         self._initialize_bytecode_cache()
 
-
-
     def _initialize_bytecode_cache(self):
         if self._bytecode_cache["enabled"]:
             cls = utils.load_class(self._bytecode_cache["backend"])
