@@ -3,33 +3,32 @@
 from django.contrib.humanize.templatetags import humanize
 from django_jinja import library
 
-lib = library.Library()
 
-@lib.filter
+@library.filter
 def ordinal(source):
     return humanize.ordinal(source)
 
 
-@lib.filter
+@library.filter
 def intcomma(source, use_l10n=True):
     return humanize.intcomma(source, use_l10n)
 
 
-@lib.filter
+@library.filter
 def intword(source):
     return humanize.intword(source)
 
 
-@lib.filter
+@library.filter
 def apnumber(source):
     return humanize.apnumber(source)
 
 
-@lib.filter
+@library.filter
 def naturalday(source, arg=None):
     return humanize.naturalday(source, arg)
 
 
-@lib.filter
+@library.filter
 def naturaltime(source):
     return humanize.naturaltime(source)
